@@ -3,7 +3,7 @@ package Algorithm::Easing;
 use strict;
 use warnings;
 
-our $VERSION = '0.97';
+our $VERSION = '0.997';
 
 1;
 
@@ -73,55 +73,18 @@ For ease of use, there is an included Mediator class.  The Mediator class permit
 
 =cut
 
-=head1 USAGE
-
-Read of a usage example using the proper mediator :
-
-    ## with mediator
-
-    use Algorithm::Easing;
-    use Algorithm::Easing::Mediator;
-    use Algorithm::Easing::Bounce;
-
-    # this example produces traditional 'bounce' output;
-
-    my $translation_mediator = Algorithm::Easing::Mediator->new(Algorithm::Easing::Bounce->new);
-
-    # total time for eased translation as a real positive integer value
-    my $t = 2.5;
-
-    # begin
-    my $b = 0;
-
-    # change
-    my $c = 240;
-
-    # time passed in seconds as a real positive integer between each frame
-    my $frame_time = 0.0625;
-
-    my @p = [319,0];
-
-    for(my $d = 0; $d < 2.5; $d += 0.0625) {
-        $p[1] = $translation_mediator->ease_out($t,$b,$c,$d)
-
-        # plot
-        ...;
-    }
-
-=cut
-
 =head1 METHODS
 
 =head2 ease_none
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -129,15 +92,15 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
@@ -146,15 +109,15 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
@@ -163,15 +126,15 @@ This method is used to ease out between two positive real whole integers as an i
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
