@@ -101,7 +101,7 @@ Algorithm::Easing::Exponential - Calculate eased translations between two positi
 =cut
 
 =head2 ease_none
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -118,7 +118,7 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -135,7 +135,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -152,7 +152,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
