@@ -36,11 +36,14 @@ sub ease_both  {
 
     return $b if ($t < EPSILON);
     return $c if ($d < EPSILON);
-
-    if (($t /= $d / 2) < 1) {
+    
+    $t /= $d / 2;
+    
+    if ($t < 1) {
         return (($c / 2) * ($t * $t)) + $b;
     }
-    return -$c / 2 * ((($t - 2)*(--$t)) - 1) + $b;
+    $t--;
+    return -$c / 2 * ($t * ($t - 2) - 1) + $b;
 }
 
 1;
