@@ -93,7 +93,7 @@ Algorithm::Easing::Quartinion - Calculate eased translations between two positiv
 =cut
 
 =head2 ease_none
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -110,7 +110,7 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -127,7 +127,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
@@ -144,7 +144,7 @@ This method is used to ease in between two positive real whole integers as an in
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
         Parameters : 
             Let t be time,
